---
name: Feature request
about: I want to request a new feature
title: ''
labels: feature-request
assignees: ''

---

**Describe the new feature you'd like**
A clear and concise description of what you want to happen. E.g. "I love how this package can evolve populations, but I think a great improvement would be for it to also do my taxes."

**Any suggestions for how to implement this**
Is there a particular way you would implement this? How could this integrate into the existing code?

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]
